This function checks what are available nodes to split and then call
find_split() on each node, then decide which node creates best split, and
call splitter() to perform the split.
checkem(
toclust.fd,
frame,
cloc,
dist,
dsubs,
dsubsname,
weights,
minbucket,
minsplit,
spliton,
method
)It is not supposed to return anything because global environment was used. However, if there is nothing left to split, it returns 0 to tell the caller to stop running the loop.
A functional data object (i.e., having class fd) created
from fda package. See fda::fd().
The split tree transferred as data frame.
Vector of current cluster membership.
Distance matrix of all observations in the data.
Distance matrix calculated on each subregion. A three-dimensional matrix.
Subregion names.
(Currently unused) Weights on observations.
The minimum number of data points in one cluster allowed.
The minimum number of observations that must exist in a node in order for a split to be attempted.
Restrict the partitioning on a specific set of subregions.
The clustering method you want to run in each subregion. Can be
chosen between pam and ward.